@@ -101,7 +101,7 @@ openapi_schema = {
 }
 
 
-def test_openapi_scheme():
+def test_openapi_schema():
     response = client.get("/openapi.json")
     assert response.status_code == 200
     assert response.json() == openapi_schema
@@ -143,6 +143,5 @@ item_id_not_int = {
 )
 def test_post_body(path, body, expected_status, expected_response):
     response = client.put(path, json=body)
-    print(response.text)
     assert response.status_code == expected_status
     assert response.json() == expected_response
